@@ -1,14 +1,14 @@
-#include <sysdeps.h>
+#include <bglibs/sysdeps.h>
 #include <ctype.h>
 #include <pwd.h>
 #include <string.h>
 
-#include <iobuf/iobuf.h>
-#include <msg/msg.h>
-#include <msg/wrap.h>
-#include <str/env.h>
-#include <str/iter.h>
-#include <str/str.h>
+#include <bglibs/iobuf.h>
+#include <bglibs/msg.h>
+#include <bglibs/wrap.h>
+#include <bglibs/envstr.h>
+#include <bglibs/striter.h>
+#include <bglibs/str.h>
 
 #include "bcron.h"
 
