@@ -1,8 +1,8 @@
-#include <sysdeps.h>
+#include <bglibs/sysdeps.h>
 
-#include <msg/msg.h>
-#include <msg/wrap.h>
-#include <str/str.h>
+#include <bglibs/msg.h>
+#include <bglibs/wrap.h>
+#include <bglibs/str.h>
 
 #include "bcron.h"
 
