@@ -24,6 +24,7 @@ done
 export USER=`whoami`
 export HOST=`hostname -f`
 export SHOST=`hostname -s`
+export BCRON_SOCKET=$tmp/spool-sock
 export BCRON_SPOOL=$tmp/spool
 export BCRON_USER=$USER
 export BCRONTAB_SOCKET=$tmp/socket
@@ -75,6 +76,16 @@ stopsched() {
     ' <$tmp/sched-log
 }
 
+startspool() {
+    spool_pid=$( unixserver $BCRON_SOCKET $src/bcron-spool > $tmp/spool-log 2>&1 & echo $! )
+    sleep 1
+}
+
+stopspool() {
+    kill $spool_pid
+    cat $tmp/spool-log | sed -e 's/\[[0-9]*\]:/[#]:/'
+}
+
 catsub() {
     cat -v "$@" \
     | sed -e "
@@ -117,7 +128,7 @@ run_compare_test() {
 
 runtest() {
 echo crontab > $CRONTABS/$USER
-echo -n "L$USER" | spoolcmd
+printf "L$USER" | spoolcmd
 rm -f $CRONTABS/$USER
 }
 vecho "Running test tests/spool-list-gooduser "
@@ -132,7 +143,7 @@ END_OF_TEST_RESULTS
 runtest() {
 touch $CRONTABS/$USER
 chmod 000 $CRONTABS/$USER
-echo -n "L$USER" | spoolcmd
+printf "L$USER" | spoolcmd
 rm -f $CRONTABS/$USER
 }
 vecho "Running test tests/spool-list-perms "
@@ -144,7 +155,7 @@ END_OF_TEST_RESULTS
 ##### Test tests/spool-delete-nouser #####
 
 runtest() {
-echo -n "Rxyzzy$USER" | spoolcmd
+printf "Rxyzzy$USER" | spoolcmd
 }
 vecho "Running test tests/spool-delete-nouser "
 run_compare_test tests/spool-delete-nouser  <<END_OF_TEST_RESULTS
@@ -418,7 +429,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 rm -f $CRONTABS/$USER
-echo -n "L$USER" | spoolcmd
+printf "L$USER" | spoolcmd
 }
 vecho "Running test tests/spool-list-missing "
 run_compare_test tests/spool-list-missing  <<END_OF_TEST_RESULTS
@@ -426,11 +437,46 @@ run_compare_test tests/spool-list-missing  <<END_OF_TEST_RESULTS
 END_OF_TEST_RESULTS
 
 
+##### Test tests/bcrontab #####
+
+runtest() {
+startspool
+
+bcrontab -l
+echo $?
+
+echo 'Test crontab' >$CRONTABS/$USER
+bcrontab -l
+echo $?
+rm -f $CRONTABS/$USER
+
+bcrontab -l -u nobody
+echo $?
+
+echo
+stopspool
+}
+vecho "Running test tests/bcrontab "
+run_compare_test tests/bcrontab  <<END_OF_TEST_RESULTS
+bcrontab: Fatal: Crontab does not exist
+111
+Test crontab
+0
+bcrontab: Fatal: Username does not match invoking UID
+111
+
+bcron-spool[#]: L bruce
+bcron-spool[#]: Fatal: bruce: Crontab does not exist
+bcron-spool[#]: L bruce
+bcron-spool[#]: Fatal: nobody: Username does not match invoking UID
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/spool-delete-good #####
 
 runtest() {
 touch $CRONTABS/$USER
-echo -n "R$USER" | spoolcmd
+printf "R$USER" | spoolcmd
 test -e $CRONTABS/$USER && echo File still exists.
 }
 vecho "Running test tests/spool-delete-good "
@@ -638,7 +684,7 @@ END_OF_TEST_RESULTS
 
 runtest() {
 touch $CRONTABS/root
-echo -n "Rroot" | spoolcmd
+printf "Rroot" | spoolcmd
 test -e $CRONTABS/root && echo File still exists.
 }
 vecho "Running test tests/spool-delete-baduser "
